@@ -9,14 +9,14 @@ History:
 
 
 from lxml import html
+
+from juriscraper.lib.string_utils import convert_date_string, titlecase
 from juriscraper.OpinionSite import OpinionSite
-from juriscraper.lib.string_utils import titlecase
-from juriscraper.lib.string_utils import convert_date_string
 
 
 class Site(OpinionSite):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.url = "http://court-url.gov/some-path.html"
         # Complete this variable if you create a backscraper.
@@ -252,5 +252,5 @@ class Site(OpinionSite):
         This can also be used to hold notes useful to future backscraper
         development.
         """
-        self.url = "http://example.com/new/url/%s" % date_str
+        self.url = f"http://example.com/new/url/{date_str}"
         self.html = self._download()
