@@ -7,7 +7,7 @@ from juriscraper.opinions.united_states.state import cal
 
 class Site(cal.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.court_code = "A"
         self.division = "1st App. Dist."
