@@ -7,14 +7,14 @@
 
 
 from datetime import date, timedelta
+
+from juriscraper.lib.string_utils import convert_date_string, titlecase
 from juriscraper.OpinionSite import OpinionSite
-from juriscraper.lib.string_utils import titlecase
-from juriscraper.lib.string_utils import convert_date_string
 
 
 class Site(OpinionSite):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.case_date = date.today()
         self.a_while_ago = date.today() - timedelta(days=20)
@@ -37,28 +37,28 @@ class Site(OpinionSite):
             # This is an arbitrary date that we need to set
             # for our compar.json test to pass
             self.case_date = convert_date_string("2017-08-14")
-        return super(Site, self)._download(request_dict=request_dict)
+        return super()._download(request_dict=request_dict)
 
     def _get_case_names(self):
-        path = "{base}/td[2]/text()".format(base=self.base_path)
+        path = f"{self.base_path}/td[2]/text()"
         return [titlecase(e) for e in self.html.xpath(path)]
 
     def _get_download_urls(self):
-        path = "{base}/td[6]/a/@href".format(base=self.base_path)
+        path = f"{self.base_path}/td[6]/a/@href"
         return list(self.html.xpath(path))
 
     def _get_case_dates(self):
         return [self.case_date] * int(
-            self.html.xpath("count({base})".format(base=self.base_path))
+            self.html.xpath(f"count({self.base_path})")
         )
 
     def _get_precedential_statuses(self):
         return ["Published"] * len(self.case_names)
 
     def _get_docket_numbers(self):
-        path = "{base}/td[1]/text()".format(base=self.base_path)
+        path = f"{self.base_path}/td[1]/text()"
         return list(self.html.xpath(path))
 
     def _get_dispositions(self):
-        path = "{base}/td[4]/text()".format(base=self.base_path)
+        path = f"{self.base_path}/td[4]/text()"
         return [titlecase(e) for e in self.html.xpath(path)]
