@@ -12,7 +12,7 @@ from juriscraper.opinions.united_states.state import ky
 
 class Site(ky.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.parameters[
             "index"
