@@ -1,4 +1,5 @@
-""" Scraper for Pennsylvania Commonwealth Court
+"""
+Scraper for Pennsylvania Commonwealth Court
 CourtID: pacomm
 Court Short Name: pacomm
 Author: Andrei Chelaru
@@ -18,13 +19,12 @@ from juriscraper.opinions.united_states.state import pa
 
 class Site(pa.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.url = (
-            "http://www.pacourts.us/assets/rss/CommonwealthOpinionsRss.ashx"
-        )
+        self.url = "https://www.pacourts.us/Rss/Opinions/Commonwealth/"
         self.set_regex(r"(.*)(?:- |et al.\s+)(\d+.*\d{4})")
         self.base = (
             "//item[not(contains(title/text(), 'Judgment List'))]"
             "[not(contains(title/text(), 'Reargument Table'))]"
+            "[not(contains(title/text(), 'Order Amending Rules'))]"
         )
