@@ -3,7 +3,7 @@ from juriscraper.opinions.united_states.state import va
 
 class Site(va.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.url = "http://www.courts.state.va.us/wpcau.htm"
         self.court_id = self.__module__
 
