@@ -3,7 +3,7 @@ from juriscraper.opinions.united_states.state import washctapp_p
 
 class Site(washctapp_p.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.courtLevel = "C"
         self.pubStatus = "UNP"
