@@ -1,12 +1,11 @@
+from datetime import date, datetime, timedelta
+
 from juriscraper.OpinionSite import OpinionSite
-from datetime import date
-from datetime import datetime
-from datetime import timedelta
 
 
 class Site(OpinionSite):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.url = "http://pacer.ca4.uscourts.gov/cgi-bin/opinions.pl"
         self.court_id = self.__module__
         td = date.today()
