@@ -1,15 +1,16 @@
+import time
+from datetime import date
+
+from lxml import html
+
 from juriscraper.opinions.united_states_backscrapers.federal_special import (
     cit_2010,
 )
 
-import time
-from datetime import date
-from lxml import html
-
 
 class Site(cit_2010.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.url = "http://www.cit.uscourts.gov/SlipOpinions/SlipOps-2009.html"
         self.court_id = self.__module__
 
