@@ -1,12 +1,10 @@
-# coding=utf-8
 import re
+from typing import Tuple
+from urllib.parse import urljoin
 
-import six
-from lxml import etree
 from lxml.html import HtmlElement
-from six.moves.urllib.parse import urljoin
+from requests import Response
 
-from .utils import is_pdf, make_doc1_url
 from ..lib.html_utils import (
     clean_html,
     fix_links_in_lxml_tree,
@@ -16,6 +14,7 @@ from ..lib.html_utils import (
     strip_bad_html_tags_insecure,
 )
 from ..lib.log_tools import make_default_logger
+from .utils import is_pdf, make_doc1_url
 
 logger = make_default_logger()
 
@@ -31,10 +30,10 @@ def re_xpath(self, path):
 HtmlElement.re_xpath = re_xpath
 
 
-class BaseReport(object):
+class BaseReport:
     """A base report for working with pages on PACER."""
 
-    REDIRECT_REGEX = re.compile('window\.\s*?location\s*=\s*"(.*)"\s*;')
+    REDIRECT_REGEX = re.compile(r'window\.\s*?location\s*=\s*"(.*)"\s*;')
 
     # Subclasses should override PATH
     PATH = ""
@@ -44,7 +43,7 @@ class BaseReport(object):
     # strings below are converted to \s whitespace searches using regexes.
     ERROR_STRINGS = [
         "MetaMask.*web3",
-        'console\.log\(".*CloudMask',
+        r'console\.log\(".*CloudMask',
         "Drumpf",
     ]
 
@@ -58,12 +57,9 @@ class BaseReport(object):
     @property
     def url(self):
         if self.court_id == "psc":
-            return "https://dcecf.psc.uscourts.gov/%s" % self.PATH
+            return f"https://dcecf.psc.uscourts.gov/{self.PATH}"
         else:
-            return "https://ecf.%s.uscourts.gov/%s" % (
-                self.court_id,
-                self.PATH,
-            )
+            return f"https://ecf.{self.court_id}.uscourts.gov/{self.PATH}"
 
     def query(self, *args, **kwargs):
         """Query PACER and set self.response with the response."""
@@ -92,8 +88,8 @@ class BaseReport(object):
         :return: None
         """
         assert isinstance(
-            text, six.text_type
-        ), "Input must be unicode, not %s" % type(text)
+            text, str
+        ), f"Input must be unicode, not {type(text)}"
         text = clean_html(text)
         self.check_validity(text)
         if self.is_valid:
@@ -101,7 +97,7 @@ class BaseReport(object):
             self.tree = strip_bad_html_tags_insecure(tree)
             self.tree.rewrite_links(fix_links_in_lxml_tree, base_href=self.url)
 
-    def check_validity(self, text):
+    def check_validity(self, text: str) -> None:
         """Place sanity checks here to make sure that the returned text is
         valid and not an error page or some other kind of problem.
 
@@ -109,7 +105,7 @@ class BaseReport(object):
         """
         for error_string in self.ERROR_STRINGS:
             error_string_re = re.compile(
-                "\s+".join(error_string.split()), flags=re.I
+                r"\s+".join(error_string.split()), flags=re.I
             )
             if error_string_re.search(text):
                 self.is_valid = False
@@ -121,12 +117,16 @@ class BaseReport(object):
         """Extract the data from the tree and return it."""
         raise NotImplementedError(".data() must be overridden.")
 
-    def _query_pdf_download(self, pacer_case_id, pacer_doc_id, got_receipt):
+    def _query_pdf_download(
+        self,
+        pacer_case_id: str,
+        pacer_doc_id: str,
+        pacer_magic_num: str,
+        got_receipt: str,
+    ) -> Tuple[Response, str]:
         """Query the doc1 download URL.
 
-        :param pacer_case_id: The case ID for the case. Used for disambiguating
-        which case the document is associated with when a pacer_doc_id is used
-        in multiple cases.
+        :param pacer_case_id: The ID of the case
         :param pacer_doc_id: The doc id for the document
         :param got_receipt: Whether to get the receipt for the page ('0') or
         get the PDF itself ('1').
@@ -134,6 +134,18 @@ class BaseReport(object):
         """
         url = make_doc1_url(self.court_id, pacer_doc_id, True)
         data = {
+            # Sending the case ID is important if you want to get PDF headers.
+            # Without the case ID, PACER won't know what case it is, and won't
+            # be able to add the correct headers. That'd suggest that the case
+            # ID should always be sent. Unfortunately though, in many criminal
+            # cases, there are documents from other related cases, and at least
+            # in CourtListener, we do a bad job of keeping track of which doc
+            # is from which related criminal case. If you send the *wrong* case
+            # ID, you get no document at all. Though you do get a useful error
+            # message. As a result, the approach we take in self.download_pdf
+            # is to try it with the case ID, and then if we see that error
+            # message, we try it again without the case ID. We won't get the
+            # headers in that case, but we'll at least get the document.
             "caseid": pacer_case_id,
             "got_receipt": got_receipt,
             # Include the PDF header where possible. Different courts allow
@@ -147,12 +159,17 @@ class BaseReport(object):
             "pdf_header": "1",
             "pdf_toggle_possible": "1",
         }
+
+        # This is not always set, so we give it an option here.
+        if pacer_magic_num is not None:
+            data["magic_num"] = pacer_magic_num
+
         timeout = (60, 300)
-        logger.info("POSTing URL: %s with params: %s" % (url, data))
+        logger.info(f"POSTing URL: {url} with params: {data}")
         r = self.session.post(url, data=data, timeout=timeout)
         return r, url
 
-    def download_pdf(self, pacer_case_id, pacer_doc_id):
+    def download_pdf(self, pacer_case_id, pacer_doc_id, pacer_magic_num=None):
         """Download a PDF from PACER.
 
         Note that this doesn't support attachments yet.
@@ -161,9 +178,18 @@ class BaseReport(object):
         (is not sealed, gone, etc.). Else, returns None.
         """
         r, url = self._query_pdf_download(
-            pacer_case_id, pacer_doc_id, got_receipt="1"
+            pacer_case_id, pacer_doc_id, pacer_magic_num, got_receipt="1"
         )
 
+        if "Cannot locate the case with caseid" in r.text:
+            # This document is from a different docket, but is included in this
+            # docket. Probably a criminal case with the doppelganger bug. Try
+            # again, but do so without the pacer_case_id. This should work, but
+            # will omit the blue header on the PDFs.
+            r, url = self._query_pdf_download(
+                None, pacer_doc_id, pacer_magic_num, got_receipt="1"
+            )
+
         if "This document is not available" in r.text:
             logger.error(
                 "Document not available in case: %s at %s", url, pacer_case_id
@@ -177,6 +203,13 @@ class BaseReport(object):
                 url,
             )
             return None
+        if "You do not have access to this transcript." in r.text:
+            logger.warning(
+                "Unable to get transcript %s in case %s.",
+                pacer_doc_id,
+                url,
+            )
+            return None
 
         # Some pacer sites use window.location in their JS, so we have to look
         # for that. See: oknd, 13-cv-00357-JED-FHM, doc #24. But, be warned,
@@ -226,12 +259,12 @@ class BaseReport(object):
 
         return r
 
-    def is_pdf_sealed(self, pacer_case_id, pacer_doc_id):
+    def is_pdf_sealed(self, pacer_case_id, pacer_doc_id, pacer_magic_num=None):
         """Check if a PDF is sealed without trying to actually download
         it.
         """
         r, url = self._query_pdf_download(
-            pacer_case_id, pacer_doc_id, got_receipt="0"
+            pacer_case_id, pacer_doc_id, pacer_magic_num, got_receipt="0"
         )
         sealed = "You do not have permission to view this document."
         return sealed in r.content
